@@ -1,22 +1,37 @@
 #' Test measurement invariance of composites
-#'
-#' This functions performs the test for measurement invariance of composites
-#' proposed by \insertCite{Henseler2016;textual}{cSEM}.
-#'
-#' The test is only meaningful for concepts modeled as composites.
-#'
-#' If more than two groups are to be compared issues related to multiple testing
-#' should be taken into account.
 #' 
-#' Models containing second-order constructs are not supported yet.
+#' \lifecycle{stable}
 #'
-#' The number of permutation runs defaults to `args_default()$.R` for performance reasons.
-#' According to \insertCite{Henseler2016;textual}{cSEM} the number of permutations should 
-#' be at least 5000 for assessment to be sufficiently reliable.
+#' The functions performs the permutation-based test for measurement invariance 
+#' of composites across groups proposed by \insertCite{Henseler2016;textual}{cSEM}. 
+#' According to the authors assessing measurement invariance in composite 
+#' models can be assessed by a three-step procedure. The first two steps 
+#' involve an assessment of configural and compositional invariance. 
+#' The third steps involves mean and variance comparisons across groups. 
+#' Assessment of configural invariance is qualitative in nature and hence 
+#' not assessed by the [testMICOM()] function. 
+#' 
+#' As [testMICOM()] requires at least two groups, `.object` must be of 
+#' class `cSEMResults_multi`. As of version 0.2.0 of the package, [testMICOM()] 
+#' does not support models containing second-order constructs.
+#'  
+#' It is possible to compare more than two groups, however, multiple-testing 
+#' issues arise in this case. To adjust p-values in this case several p-value 
+#' adjustments are available via the `approach_p_adjust` argument. 
+#' 
+#' The remaining arguments set the number of permutation runs to conduct 
+#' (`.R`), the random number seed (`.seed`), 
+#' instructions how inadmissible results are to be handled (`handle_inadmissibles`),
+#' and whether the function should be verbose in a sense that progress is printed
+#' to the console.
+#'
+#' The number of permutation runs defaults to `args_default()$.R` for 
+#' performance reasons. According to \insertCite{Henseler2016;textual}{cSEM} 
+#' the number of permutations should be at least 5000 for assessment to be 
+#' sufficiently reliable.
 #'
 #' @usage testMICOM(
 #'  .object               = NULL,
-#'  .alpha                = 0.05,
 #'  .approach_p_adjust    = "none",
 #'  .handle_inadmissibles = c("drop", "ignore", "replace"), 
 #'  .R                    = 499,
@@ -46,7 +61,6 @@
 
 testMICOM <- function(
   .object               = NULL,
-  .alpha                = 0.05,
   .approach_p_adjust    = "none",
   .handle_inadmissibles = c("drop", "ignore", "replace"),
   .R                    = 499,
@@ -153,9 +167,9 @@ testMICOM <- function(
     
     ## Permutation ---------------------------------------------------------------
     # Start progress bar
-    if(.verbose){
-      pb <- txtProgressBar(min = 0, max = .R, style = 3)
-    }
+    # if(.verbose){
+    #   pb <- txtProgressBar(min = 0, max = .R, style = 3)
+    # }
     
     # Save old seed and restore on exit! This is important since users may have
     # set a seed before, in which case the global seed would be
@@ -180,75 +194,79 @@ testMICOM <- function(
     ref_dist         <- list()
     n_inadmissibles  <- 0
     counter <- 0
-    repeat{
-      # Counter
-      counter <- counter + 1
-      
-      # Permutate data
-      X_temp <- cbind(X, id = sample(id))
-      
-      # Replace the old dataset by the new permutated dataset
-      arguments[[".data"]] <- X_temp
-      
-      # Estimate model
-      Est_temp <- do.call(csem, arguments)   
-      
-      # Check status
-      status_code <- sum(unlist(verify(Est_temp)))
-      
-      # Distinguish depending on how inadmissibles should be handled
-      if(status_code == 0 | (status_code != 0 & .handle_inadmissibles == "ignore")) {
-        # Compute if status is ok or .handle inadmissibles = "ignore" AND the status is 
-        # not ok
+    progressr::with_progress({
+      progress_bar_csem <- progressr::progressor(along = 1:.R)
+      repeat{
+        # Counter
+        counter <- counter + 1
+        progress_bar_csem(message = sprintf("Permutation run = %g", counter))
         
-        ## Compute weights for each group and use these to compute proxies/scores using
-        # the pooled data (= the original combined data). Note that these
-        # scores are unstandardized, however since we consider the correlation 
-        # it does not matter whether we consider standardized or unstandardized 
-        # proxies
-        H_temp <- lapply(Est_temp, function(x) X %*% t(x$Estimates$Weight_estimates))
+        # Permutate data
+        X_temp <- cbind(X, id = sample(id))
         
-        ## Compute the correlation of the scores for all group combinations
-        # Get the scores for all group combinations
-        H_combn_temp <- utils::combn(H_temp, 2, simplify = FALSE)
+        # Replace the old dataset by the new permutated dataset
+        arguments[[".data"]] <- X_temp
         
-        # Compute the correlation c for each group combination
-        c_temp <- lapply(H_combn_temp, function(x) diag(cor(x[[1]], x[[2]])))
+        # Estimate model
+        Est_temp <- do.call(csem, arguments)   
         
-        # Set the names for each group combination
-        names(c_temp) <- utils::combn(names(H_temp), 2, FUN = paste0, 
-                                      collapse = "_", simplify = FALSE)
+        # Check status
+        status_code <- sum(unlist(verify(Est_temp)))
         
-        ref_dist[[counter]] <- c_temp
+        # Distinguish depending on how inadmissibles should be handled
+        if(status_code == 0 | (status_code != 0 & .handle_inadmissibles == "ignore")) {
+          # Compute if status is ok or .handle inadmissibles = "ignore" AND the status is 
+          # not ok
+          
+          ## Compute weights for each group and use these to compute proxies/scores using
+          # the pooled data (= the original combined data). Note that these
+          # scores are unstandardized, however since we consider the correlation 
+          # it does not matter whether we consider standardized or unstandardized 
+          # proxies
+          H_temp <- lapply(Est_temp, function(x) X %*% t(x$Estimates$Weight_estimates))
+          
+          ## Compute the correlation of the scores for all group combinations
+          # Get the scores for all group combinations
+          H_combn_temp <- utils::combn(H_temp, 2, simplify = FALSE)
+          
+          # Compute the correlation c for each group combination
+          c_temp <- lapply(H_combn_temp, function(x) diag(cor(x[[1]], x[[2]])))
+          
+          # Set the names for each group combination
+          names(c_temp) <- utils::combn(names(H_temp), 2, FUN = paste0, 
+                                        collapse = "_", simplify = FALSE)
+          
+          ref_dist[[counter]] <- c_temp
+          
+        } else if(status_code != 0 & .handle_inadmissibles == "drop") {
+          # Set list element to zero if status is not okay and .handle_inadmissibles == "drop"
+          ref_dist[[counter]] <- NA
+          
+        } else {# status is not ok and .handle_inadmissibles == "replace"
+          # Reset counter and raise number of inadmissibles by 1
+          counter <- counter - 1
+          n_inadmissibles <- n_inadmissibles + 1
+        }
         
-      } else if(status_code != 0 & .handle_inadmissibles == "drop") {
-        # Set list element to zero if status is not okay and .handle_inadmissibles == "drop"
-        ref_dist[[counter]] <- NA
+        # Update progress bar
+        # if(.verbose){
+        #   setTxtProgressBar(pb, counter)
+        # }
         
-      } else {# status is not ok and .handle_inadmissibles == "replace"
-        # Reset counter and raise number of inadmissibles by 1
-        counter <- counter - 1
-        n_inadmissibles <- n_inadmissibles + 1
-      }
-      
-      # Update progress bar
-      if(.verbose){
-        setTxtProgressBar(pb, counter)
-      }
-      
-      # Break repeat loop if .R results have been created.
-      if(length(ref_dist) == .R) {
-        break
-      } else if(counter + n_inadmissibles == 10000) { 
-        ## Stop if 10000 runs did not result in insufficient admissible results
-        stop("Not enough admissible result.", call. = FALSE)
-      }
-    } # END repeat 
+        # Break repeat loop if .R results have been created.
+        if(length(ref_dist) == .R) {
+          break
+        } else if(counter + n_inadmissibles == 10000) { 
+          ## Stop if 10000 runs did not result in insufficient admissible results
+          stop("Not enough admissible result.", call. = FALSE)
+        }
+      } # END repeat 
+    }) # END with_progress
     
     # close progress bar
-    if(.verbose){
-      close(pb)
-    }
+    # if(.verbose){
+    #   close(pb)
+    # }
     
     # Delete potential NA's
     ref_dist <- Filter(Negate(anyNA), ref_dist)
@@ -258,7 +276,7 @@ testMICOM <- function(
     temp <- split(as.data.frame(temp), rownames(temp))
     
     # Order alphas (decreasing order)
-    .alpha <- .alpha[order(.alpha)]
+    # .alpha <- .alpha[order(.alpha)]
     # critical_values_step2 <- lapply(lapply(temp, as.matrix), matrixStats::colQuantiles, 
     #                                 probs = .alpha, drop = FALSE) # lower quantile needed, hence 
     # alpha and not 1 - alpha
@@ -286,16 +304,16 @@ testMICOM <- function(
     # Decision 
     # TRUE = p-value > alpha --> not reject
     # FALSE = sufficient evidence against the H0 --> reject
-    decision_step2 <- lapply(padjusted_step2, function(adjust_approach){ # over the different p adjustments
-      temp <- lapply(.alpha, function(alpha){# over the different significance levels
-        lapply(adjust_approach,function(group_comp){# over the different group comparisons
-          # check whether the p values are larger than a certain alpha
-          as.matrix(group_comp > alpha,ncol=1)
-        })
-      })
-      names(temp) <- paste0(.alpha*100, "%")
-      temp
-    })
+    # decision_step2 <- lapply(padjusted_step2, function(adjust_approach){ # over the different p adjustments
+    #   temp <- lapply(.alpha, function(alpha){# over the different significance levels
+    #     lapply(adjust_approach,function(group_comp){# over the different group comparisons
+    #       # check whether the p values are larger than a certain alpha
+    #       as.matrix(group_comp > alpha,ncol=1)
+    #     })
+    #   })
+    #   names(temp) <- paste0(.alpha*100, "%")
+    #   temp
+    # })
     # TRUE do not reject; FALSE: reject
 
     ### Step 3 - Equal mean values and variances==================================
@@ -392,16 +410,16 @@ testMICOM <- function(
     names(padjusted_mean) <- .approach_p_adjust
     
     # Make decision
-    decision_mean <- lapply(padjusted_mean, function(adjust_approach){ # over the different p adjustments
-      temp <- lapply(.alpha, function(alpha){# over the different significance levels
-        lapply(adjust_approach,function(group_comp){# over the different group comparisons
-          # check whether the p values are larger than a certain alpha
-          as.matrix(group_comp > alpha,ncol=1)
-        })
-      })
-      names(temp) <- paste0(.alpha*100, "%")
-      temp
-    })
+    # decision_mean <- lapply(padjusted_mean, function(adjust_approach){ # over the different p adjustments
+    #   temp <- lapply(.alpha, function(alpha){# over the different significance levels
+    #     lapply(adjust_approach,function(group_comp){# over the different group comparisons
+    #       # check whether the p values are larger than a certain alpha
+    #       as.matrix(group_comp > alpha,ncol=1)
+    #     })
+    #   })
+    #   names(temp) <- paste0(.alpha*100, "%")
+    #   temp
+    # })
     # TRUE: do not reject; FALSE: reject
     
     
@@ -433,16 +451,16 @@ testMICOM <- function(
     
     names(padjusted_var) <- .approach_p_adjust
     # Make decision
-    decision_var <- lapply(padjusted_var, function(adjust_approach){ # over the different p adjustments
-      temp <- lapply(.alpha, function(alpha){# over the different significance levels
-        lapply(adjust_approach,function(group_comp){# over the different group comparisons
-          # check whether the p values are larger than a certain alpha
-          as.matrix(group_comp > alpha,ncol=1)
-        })
-      })
-      names(temp) <- paste0(.alpha*100, "%")
-      temp
-    })
+    # decision_var <- lapply(padjusted_var, function(adjust_approach){ # over the different p adjustments
+    #   temp <- lapply(.alpha, function(alpha){# over the different significance levels
+    #     lapply(adjust_approach,function(group_comp){# over the different group comparisons
+    #       # check whether the p values are larger than a certain alpha
+    #       as.matrix(group_comp > alpha,ncol=1)
+    #     })
+    #   })
+    #   names(temp) <- paste0(.alpha*100, "%")
+    #   temp
+    # })
     
     
     
@@ -474,19 +492,19 @@ testMICOM <- function(
       "Step2" = list(
         "Test_statistic"     = c,
         "P_value"            = padjusted_step2, 
-        "Decision"           = decision_step2,
+        # "Decision"           = decision_step2,
         "Bootstrap_values"   = ref_dist
       ),
       "Step3" = list(
         "Mean" = list(
           "Test_statistic"     = teststat_mean,
-          "P_value"            = padjusted_mean, 
-          "Decision"           = decision_mean
+          "P_value"            = padjusted_mean 
+          # "Decision"           = decision_mean
         ),
         "Var" = list(
           "Test_statistic"     = teststat_var,
-          "P_value"            = padjusted_var, 
-          "Decision"           = decision_var
+          "P_value"            = padjusted_var
+          # "Decision"           = decision_var
         )
       ),
       "Information" = list(
